# Setting Up Your Custom Reports Project
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#prerequisites)
  * [Step 1: Install the LeanIX Reporting CLI](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#step-1:-install-the-leanix-reporting-cli)
  * [Step 2: Create Your Project Directory](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#step-2:-create-your-project-directory)
  * [Step 3: Scaffold Your Project](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#step-3:-scaffold-your-project)
  * [Step 4: Configure Your Project](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#step-4:-configure-your-project)
  * [Step 5: Install Dependencies](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#step-5:-install-dependencies)
  * [Step 6: Install Chart.js](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project#step-6:-install-chart.js)


View all
Before you start developing custom reports, configure your project using the scaffolder of the LeanIX Reporting CLI.
